@@ -8,18 +8,6 @@ from scipy.sparse import csr_matrix
 from sklearn.feature_extraction.text import TfidfVectorizer
 
 
-def combine(df1, df2):
-    left_on, right_on = get_primary_keys(df1, df2)
-    list1 = list(df1[df1.columns[left_on]])
-    list2 = list(df2[df2.columns[right_on]])
-    primary_key_joins = string_matcher(list1, list2)
-    matched_list = primary_key_joins.get_matched_list()
-    matched_list = matched_list[matched_list.similairity < 0.99]
-    df2[df2.columns[right_on]] = df2[df2.columns[right_on]].apply(lambda x: lookup(x, matched_list))
-    temp = pd.merge(df1, df2, left_on=df1.columns[left_on], right_on=df2.columns[right_on])
-    return temp
-
-
 def matrix_max_val_loc(mat):
     return np.unravel_index(np.argmax(mat, axis=None), mat.shape)
 
@@ -79,6 +67,22 @@ def lookup(string, matches_df):
         return string
 
 
+def combine(df1, df2, outer=True):
+    left_on, right_on = get_primary_keys(df1, df2)
+    list1 = list(df1[df1.columns[left_on]])
+    list2 = list(df2[df2.columns[right_on]])
+    primary_key_joins = string_matcher(list1, list2)
+    matched_list = primary_key_joins.get_matched_list()
+    matched_list = matched_list[matched_list.similairity < 0.99]
+    df2[df2.columns[right_on]] = df2[df2.columns[right_on]].apply(lambda x: lookup(x, matched_list))
+    if outer:
+        temp = pd.merge(df1, df2, left_on=df1.columns[left_on], right_on=df2.columns[right_on], how='outer')
+    else:
+        temp = pd.merge(df1, df2, left_on=df1.columns[left_on], right_on=df2.columns[right_on])
+    temp = temp.drop([df2.columns[right_on]], axis=1)
+    return temp
+
+
 class string_matcher():
     def __init__(self, list1, list2, top_n=10, similarity=0.8):
         self.list1 = list1
